#
# spec file for package nuspell
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum   5
%define libname libnuspell
Name:           nuspell
Version:        5.0.0
Release:        bp154.1.16
Summary:        A spell checker library and command-line tool
License:        LGPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://nuspell.github.io/
Source:         https://github.com/nuspell/nuspell/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  Catch2-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libicu-devel
BuildRequires:  rubygem(%{rb_default_ruby_abi}:ronn)
Requires:       hunspell

%description
Nuspell is a spell checker written in C++. It supports languages with
rich morphology and complex word compounding.

Main features are:
 - Full unicode support backed by ICU
 - Backward compatibility with Hunspell dictionary file format
 - Twofold affix stripping (for agglutinative languages, like Azeri,
   Basque, Estonian, Finnish, Hungarian, Turkish, etc.)
 - Support complex compounds (for example, Hungarian, Germand and Dutch)
 - Support language specific features (for example, special casing of
   Azeri and Turkish dotted i, or German sharp s)
 - Handle conditional affixes, circumfixes, fogemorphemes, forbidden
   words, pseudoroots and homonyms.

%package -n %{libname}%{sonum}
Summary:        A spell checker library and command-line tool
Group:          System/Libraries

%description -n %{libname}%{sonum}
Nuspell is a spell checker written in C++. It supports languages with
rich morphology and complex word compounding.

Main features are:
 - Full unicode support backed by ICU
 - Backward compatibility with Hunspell dictionary file format
 - Twofold affix stripping (for agglutinative languages, like Azeri,
   Basque, Estonian, Finnish, Hungarian, Turkish, etc.)
 - Support complex compounds (for example, Hungarian, Germand and Dutch)
 - Support language specific features (for example, special casing of
   Azeri and Turkish dotted i, or German sharp s)
 - Handle conditional affixes, circumfixes, fogemorphemes, forbidden
   words, pseudoroots and homonyms.

%package devel
Summary:        Files for developing with Nuspell
Group:          Development/Libraries/C and C++
Requires:       nuspell = %{version}-%{release}

%description devel
Header files and definitions for developing with Nuspell.

%prep
%autosetup

%build
%cmake -DBUILD_SHARED_LIBS:BOOL=ON \
       -DBUILD_TESTING:BOOL=ON  \
       -DCMAKE_SKIP_RPATH:BOOL=OFF \
 ..

%cmake_build

pushd ../
doxygen
popd

%install
%cmake_install

%post -n %{libname}%{sonum} -p /sbin/ldconfig
%postun -n %{libname}%{sonum} -p /sbin/ldconfig

%check
%ctest

%files -n %{name}
%{_bindir}/nuspell

%files -n %{libname}%{sonum}
%doc README.md CHANGELOG.md AUTHORS
%license COPYING.LESSER COPYING
%{_libdir}/%{libname}.so.%{version}
%exclude %{_datadir}/doc/nuspell/README.md

%files devel
%{_includedir}/%{name}
%{_libdir}/%{libname}.so
%{_libdir}/%{libname}.so.%{sonum}
%{_libdir}/pkgconfig/nuspell.pc
%{_libdir}/cmake/%{name}

%changelog
* Thu Jun 17 2021 andy great <andythe_great@pm.me>
- Update to version 5.0.0.
  * Fixed
  * Greatly reduce memory usage.
  * Increase speed of spellchecking.
  * Fix long lagging when generating suggestions in edge cases.
  * Fix building on OS Haiku.
  * Changed
  * Split file dictionary.hxx/cxx into multiple files. The other
    files are implementation details and the public header
    dictionary.hxx is now clean of private details.
  * Removed
  * Remove functions and classes that were deprecated in v4.x.
* Tue Jan 12 2021 andy great <andythe_great@pm.me>
- Update to version 4.2.0.
  * Deprecate functions that allowed non-Unicode encoding. In
    particular, Dictionary::imbue() and Dictionary::imbue_utf8().
  * Completely remove dependency on Boost. The CLI tools were
    refactored to use ICU directly.
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 4.1.0.
  * Added: Add new API for finding dictionaries on the file-system.
    It is a set of free functions located in the file finder.hxx.
  * Fixed: Improve searching for dictionaries on the file-system.
    Fix finding them on
    Fedora.
  * Deprecated: Deprecate the old API for finding dictionaries,
    i.e. the class Finder in the file finder.hxx.
- Updates since 3.1.2.
  * Fix handling CRLF line endings in .dic. Fixes #89.
  * Fix CMake scripts for unusual install prefixes.
  * Improve hash-table insertion, avoid temporaries. This improves
    loading times.
  * Switch man-page generator from Ronn to Pandoc. This changes the
    dependencies for building. See the README.
  * Fix lifetime issue (segmentation fault) in ngram-based
    suggestions.
  * Fix internal usage of std::codecvt in edge case in function
    to_wide() and to_narrow()
  * Fix not propagating recursion depth in spell_break(), which
    caused hangup.
  * Fix overwriting of PDB files when compiling with Visual Studio.
    This prevented debugging nuspell.dll.
  * Fix output of CLI tool to be more compatible to ispell and
    hunspell.
  * Boost is no longer a dependency of the library at all. It is
    still a dependency of the CLI tool.
  * Use std::string_view in the public API instead of const
    std::string&. Also use it internally at various places.
  * Build as shared library by default. Building as static is still
    possible via the CMake's variable BUILD_SHARED_LIBS.
  * The public API is annotated with dll-export/visibility
    attributes, and also some private functions are annotated needed
    for testing. This reduces the file size.
  * Use Unicode text segmentation by default in the CLI tool.
    Simple segmentation on white-space is still available via CLI
    option.
  * Delete deprecated functions in the class Finder.
  * Drop under-designed and undocumented feature in the CLI tool
    about personal dictionaries.
* Sat Jul 11 2020 andy great <andythe_great@pm.me>
- Update to version 3.1.2.
  * Fixed: Internal refactorings that reduce function templates in
    utils and finder.
  * Changed: File utils.hxx is not installed any more. It is a
    private header.
  * Deprecated: Some functions for searching dictionaries in class
    Finder are deprecated as they were searching in directories that
    no longer contain dictionaries.
* Sat Jul 11 2020 andy great <andythe_great@pm.me>
- Fix build for leap by enabling cmake rpath flag.
* Thu Jun  4 2020 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from description.
- Drop redundant (autodetected) pkgconfig require.
* Sat May 30 2020 andy great <andythe_great@pm.me>
- Add doxygen dependency, and build documentation.
* Mon May 25 2020 andy great <andythe_great@pm.me>
- Add Catch2 dependeny for test.
* Mon May 25 2020 andy great <andythe_great@pm.me>
- Enable build for share library.
* Mon May 25 2020 andy great <andythe_great@pm.me>
- Update to version 3.1.1.
  * Updated description in README.
  * Moved Hunspell files from the directory "src" into the
    directory named "external" to clarify that it is third-party
    dependency.
* Mon May 25 2020 andy great <andythe_great@pm.me>
- Enable testing.
* Sat Apr 11 2020 andy great <andythe_great@pm.me>
- Initial package release.
